from flask import Flask, request
from flask_cors import CORS
import utils as utils

config = utils.get_config_dict()
git_cmd = utils.git_cmd(config)

## komt später vom server
xsd_file_name = 'DCC_v1.8.1.xsd'

app = Flask(__name__)
CORS(app)

@app.route('/version', methods=['get'])
def version():
    app.logger.debug('hit version')
    ret = '<version>{version}</version>'.format(version=git_cmd.describe())

    return utils.xml_response(ret)

@app.route('/update', methods=['post'])
def update():
    app.logger.debug('hit update')
    req = request.get_json()
    git_cmd.pull()
    app.logger.info("pulled {log}".format(log=g.log("-n 1")))
    ret = '<ok/>'

    return utils.xml_response(ret)

@app.route('/update_xsd', methods=['post'])
def update_xsd():
    app.logger.debug('hit update xsd')
    xsd_str = utils.get_xsd(config, xsd_file_name, from_server=True)
    xsd_xml = utils.parse(xsd_str)
    if xsd_xml:
        res = utils.save_xsd(config, xsd_str, xsd_file_name)
    
    return  utils.xml_response(ret)


@app.route('/is_valid', methods=['post'])
def is_valid():
    app.logger.debug('hit validate')
    xml_str = request.data
    xml_tree = utils.parse(xml_str)
    if xml_tree:
        xsd_str = utils.get_xsd(config, xsd_file_name, from_server=False)
        res = utils.is_valid(xml_str=xml_str, xsd_str=xsd_str)
        if res:
            ret = '<ok/>'
        else:
            ret = '<error>not valid</error>'
    else:
        ret = '<error>unvalid xml data</error>'

    return  utils.xml_response(ret)


if __name__ == '__main__':
    app.run(host=config['server']['host'], port=config['server']['port'])