import json
import git
import requests
from flask import Response
from xml.etree import ElementTree as ET
import xmlschema

def get_config_dict():
    ## sollte vielleicht doch xml-datei werden
    with open('./config.json') as json_config_file:
        config = json.load(json_config_file)

    return config

def git_cmd(config):
    return git.cmd.Git(config['git']['dir'])

def get_xsd_url(config, xsd_name):
    return "{uri}/{xsd_name}".format(uri=config['xsd']['url'], xsd_name=xsd_name)

def get_xsd_path_file(config, xsd_name):
    return "{dir}/{xsd_name}".format(dir=config['xsd']['dir'], xsd_name=xsd_name)

def get_xsd(config, xsd_name, from_server=True):
    if from_server:
        url = get_xsd_url(config, xsd_name)
        xsd_str = requests.get(url).text
    else:
        path_file = get_xsd_path_file(config, xsd_name)
        xsd_str = open(path_file).read()

    return xsd_str

def save_xsd(config, xsd_str, xsd_name):
    path_file = get_xsd_path_file(config, xsd_name)
    file = open(path_file, "w")
    file.write(xsd_str)  
    
    return 'ok'

def parse(xml_str):
    try:
        tree = ET.fromstring(xml_str)
    except ET.ParseError:
        tree = None
    
    return tree

def is_valid(xml_str, xsd_str):
    tree = parse(xml_str)
    if tree:
        schema = xmlschema.XMLSchema(xsd_str)
        return schema.is_valid(tree)
    else:
        return False
    
def xml_response(xml_str):
    return Response(xml_str, content_type='text/xml; charset=utf-8')